# The FASTEST way to parse email.

```
$ pip install csirtg_mail
$ cat spam.eml | csirtg-mail -d
```

# Getting Help

Need more advanced help? [Partner with us!](https://csirtg.io/support)

# COPYRIGHT AND LICENSE

Copyright (C) 2018 [CSIRT Gadgets](http://csirtgadgets.com)

Free use of this software is granted under the terms of the [Mozilla Public License (MPLv2)](https://www.mozilla.org/en-US/MPL/2.0/).
